using System;
using System.Xml.Serialization;
using System.Collections.Generic;
using Top.Api.Util;

namespace Top.Api.Request
{
    /// <summary>
    /// TOP API: taobao.openim.tribe.sendmsg
    /// </summary>
    public class OpenimTribeSendmsgRequest : BaseTopRequest<Top.Api.Response.OpenimTribeSendmsgResponse>
    {
        /// <summary>
        /// 发送群消息
        /// </summary>
        public string Msg { get; set; }

        public TribeMsgDomain Msg_ { set { this.Msg = TopUtils.ObjectToJson(value); } } 

        /// <summary>
        /// 群id
        /// </summary>
        public Nullable<long> TribeId { get; set; }

        /// <summary>
        /// 群消息发送者，只有该群的成员才可以发送群消息
        /// </summary>
        public string User { get; set; }

        public UserDomain User_ { set { this.User = TopUtils.ObjectToJson(value); } } 

        #region ITopRequest Members

        public override string GetApiName()
        {
            return "taobao.openim.tribe.sendmsg";
        }

        public override IDictionary<string, string> GetParameters()
        {
            TopDictionary parameters = new TopDictionary();
            parameters.Add("msg", this.Msg);
            parameters.Add("tribe_id", this.TribeId);
            parameters.Add("user", this.User);
            if (this.otherParams != null)
            {
                parameters.AddAll(this.otherParams);
            }
            return parameters;
        }

        public override void Validate()
        {
            RequestValidator.ValidateRequired("msg", this.Msg);
            RequestValidator.ValidateRequired("tribe_id", this.TribeId);
            RequestValidator.ValidateRequired("user", this.User);
        }

	/// <summary>
/// UserDomain Data Structure.
/// </summary>
[Serializable]

public class UserDomain : TopObject
{
	        /// <summary>
	        /// 用户所属appkey
	        /// </summary>
	        [XmlElement("appkey")]
	        public string Appkey { get; set; }
	
	        /// <summary>
	        /// 是否是淘宝账号
	        /// </summary>
	        [XmlElement("taobao_account")]
	        public Nullable<bool> TaobaoAccount { get; set; }
	
	        /// <summary>
	        /// 用户id
	        /// </summary>
	        [XmlElement("uid")]
	        public string Uid { get; set; }
}

	/// <summary>
/// TribeMsgDomain Data Structure.
/// </summary>
[Serializable]

public class TribeMsgDomain : TopObject
{
	        /// <summary>
	        /// 是否是at消息， 0表示不是at消息，1表示at指定的用户，2表示at群里所有人
	        /// </summary>
	        [XmlElement("at_flag")]
	        public Nullable<long> AtFlag { get; set; }
	
	        /// <summary>
	        /// 当at_flag=1时，必须指定at的用户
	        /// </summary>
	        [XmlArray("atmembers")]
	        [XmlArrayItem("user")]
	        public List<UserDomain> Atmembers { get; set; }
	
	        /// <summary>
	        /// 自定义push提醒参数，格式为json字符串，该参数为空时，采用系统默认的push；设置该参数时，json字符串必选包含至少包含指定的三个key，"d", "sound", "title"
	        /// </summary>
	        [XmlElement("custom_push")]
	        public string CustomPush { get; set; }
	
	        /// <summary>
	        /// 格式为json字符串， 当消息类型为图片或语音时该参数为必选项，用于描述图片，语音的属性； 该参数json格式必须符合msg_type的要求；当消息类型为图片时，格式必须符合如下样例 ： {“height”：10, "width":10, "type":"jpg"}，当前支持3三种图片类型，gif, jpg,jpeg； 当消息类型为语音时，必须符合如下样例：{“playtime”:10,”type”:”amr”}，语音的type只支持arm
	        /// </summary>
	        [XmlElement("media_attrs")]
	        public string MediaAttrs { get; set; }
	
	        /// <summary>
	        /// 文本消息最大长度是4K，图片最大为500K。消息内容格式根据type确定。当type为文本时，内容为文本字符串；当类型为图片或语音时，内容为图片和语音的二进制base64编码生成的字符串；当类型为自定义消息时，内容必须为就送字符串格式，该字符串必须包含header字符，即{"header":{"summary":},...}
	        /// </summary>
	        [XmlElement("msg_content")]
	        public string MsgContent { get; set; }
	
	        /// <summary>
	        /// 消息类型，目前支持四中类型的消息； msg_type=0 表示普通文本消息； msg_type=2 表示语音消息； msg_type = 16表示图片消息； msg_type=17表示用户自定义消息
	        /// </summary>
	        [XmlElement("msg_type")]
	        public Nullable<long> MsgType { get; set; }
	
	        /// <summary>
	        /// 该消息是否需要push
	        /// </summary>
	        [XmlElement("push")]
	        public Nullable<bool> Push { get; set; }
}

        #endregion
    }
}
